# Lobster_L3_orderbook_reconstructor
A repository for visualizing limit order book from data provided by LOBSTER

[![Documentation Status](https://readthedocs.org/projects/lobster-l3-orderbook-reconstructor/badge/?version=latest)](https://lobster-l3-orderbook-reconstructor.readthedocs.io/en/latest/?badge=latest)
